@@ -99,6 +99,7 @@ module Control.Monad.Managed (
     MonadManaged(..),
     managed,
     managed_,
+    defer,
     with,
     runManaged,
 
@@ -108,17 +109,10 @@ module Control.Monad.Managed (
     ) where
 
 import Control.Monad.IO.Class (MonadIO(liftIO))
-#if MIN_VERSION_base(4,9,0)
 import Control.Monad.Fail as MonadFail (MonadFail(..))
-#endif
 import Control.Monad.Trans.Class (lift)
 
-#if MIN_VERSION_base(4,8,0)
 import Control.Applicative (liftA2)
-#else
-import Control.Applicative
-import Data.Monoid (Monoid(..))
-#endif
 
 #if !(MIN_VERSION_base(4,11,0))
 import Data.Semigroup (Semigroup(..))
@@ -166,12 +160,10 @@ instance MonadIO Managed where
         a <- m
         return_ a )
 
-#if MIN_VERSION_base(4,9,0)
 instance MonadFail Managed where
     fail s = Managed (\return_ -> do
         a <- MonadFail.fail s
         return_ a )
-#endif
 
 instance Semigroup a => Semigroup (Managed a) where
     (<>) = liftA2 (<>)
@@ -275,6 +267,17 @@ managed f = using (Managed f)
 managed_ :: MonadManaged m => (forall r. IO r -> IO r) -> m ()
 managed_ f = managed $ \g -> f $ g ()
 
+{-| Defer running an action until exit (via `runManaged`).
+
+For example, the following code will print \"Hello\" followed by \"Goodbye\":
+
+> runManaged $ do
+>   defer $ liftIO $ putStrLn "Goodbye"
+>   liftIO $ putStrLn "Hello"
+-}
+defer :: MonadManaged m => IO r -> m ()
+defer m = managed_ (<* m)
+
 {-| Acquire a `Managed` value
 
     This is a potentially unsafe function since it allows a resource to escape
